Function ic_kit::ic::stable_read
source · [−]pub fn stable_read(offset: StableSize, buf: &mut [u8])Expand description
Reads data from the stable memory location specified by an offset.
pub fn stable_read(offset: StableSize, buf: &mut [u8])Reads data from the stable memory location specified by an offset.