pub fn store<T: 'static>(data: T)👎Deprecated since 0.4.8:
Unsafe memory methods are deprecated, use the safer ic_kit::ic::swap method.
Store the given data to the storage.
pub fn store<T: 'static>(data: T)Unsafe memory methods are deprecated, use the safer ic_kit::ic::swap method.
Store the given data to the storage.