The famous prelude module which re exports the most useful methods.
Re-exports
pub use super::ic;pub use ic_kit_runtime as rt;Modules
A set of mock principal ids.
Structs
A call builder that let’s you create an inter-canister call which can be then sent to the destination.
Generic ID on Internet Computer.
A local replica that contains one or several canisters.
Traits
A data structure that can be deserialized from any data format supported by Serde.
A canister.
A data structure that can be serialized into any data format supported by Serde.
Functions
The balance of the canister.
The caller who has invoked this method on the canister.
ID of the current canister.
Like with, but does not initialize the data with the default value and simply returns None,
if there is no value associated with the type.
Like with_mut, but does not initialize the data with the default value and simply returns
None, if there is no value associated with the type.
Execute a future without blocking the current call. The given future is polled once initially to kickstart the async calls.
Swaps the value associated with type T with the given value, returns the old one.
Remove the current value associated with the type and return it.
Pass an immutable reference to the value associated with the given type to the closure.
Pass a mutable reference to the value associated with the given type to the closure.
Type Definitions
The type used to represent the cycles amount, which is u128 when the experimental-cycles128
feature is on and a u64 otherwise.
A type which represents either a page count or an offset in the stable storage, it’s a u64
when the experimental-stable64 feature is enabled, otherwise a u32.
Attribute Macros
Export the function as the heartbeat hook of the canister.
Export the function as the init hook of the canister.
Export the function as the inspect_message hook of the canister.
A macro to generate IC-Kit tests.
Export the function as the post_upgrade hook of the canister.
Export the function as the pre_upgrade hook of the canister.
Export a query method for the canister.
Export an update method for the canister.