pub struct Replica { /* private fields */ }
A local replica that contains one or several canisters.

Implementations

Create a new replica with the given canister.

Add the given canister to this replica.

Return the handle to a canister.

Create a new call builder on the replica, that can be used to send a request to the given canister.